# Aly_facts

## What is Aly_facts?
Aly_facts provides facts about a user on discord named entity_night aka aly aka Alyssa. This module was made for private usage.

## Installation
```shell
pip install aly_facts
```

## Guide

### Syntax
Here's the basic syntax to follow when using the module

```py
import Aly_facts as aly

result = aly.function_name()
print(result)
```

### Example
Here's an example code snippet to show the usage
```py
import Aly_facts as aly

result = aly.get_facts()
print(result)
```

### Functions
| Function      | Description                                |
|-------------------|----------------------------------------|
| get_facts()     | Returns random facts about Aly
| get_all_facts() | Returns every fact about Aly as a list |
| get_aly_pics()  | Returns random Aly pictures            |
| version()       | Returns the package version            |

## Want more functions or something changed?
Make a pull request to the [GitHub repo](https://github.com/NotFaizen/Aly_facts) or join the [discord](https://discord.gg/kqmyWNtbaY), make a ticket and ping me aka NotFaizen

## Shameless plug
### My socials
Instagram :: [notfaizen](https://www.instagram.com/notfaizen/)   
Twitter :: [TheRealFaizen](https://twitter.com/TheRealFaizen)   
Reddit :: [NotFaizen](https://www.reddit.com/user/NotFaizen)   
GitHub :: [NotFaizen](https://github.com/NotFaizen)   
Discord :: [NotFaizen](https://discord.com/users/672791500995690517)

### Discord servers you should join
Basement Developers - [Click here](https://discord.gg/mECmB39fyE)  
Basement Bots Lab - [Click here](https://discord.gg/RPmvdnR88w)  
Pop Cat Community - [Click here](https://dsc.gg/popcatcom)  
CraftBlur Official - [Click here](https://discord.gg/kqmyWNtbaY)